@@ -369,9 +369,17 @@ QUESTION_TYPE_DICT = {
     "xml-external": {
         # Only effect is to add an external instance.
     },
+    "csv-external": {
+        # Only effect is to add an external instance.
+    },
     "start-geopoint": {
         "control": {"tag": "action"},
         "bind": {"type": "geopoint"},
         "action": {"name": "odk:setgeopoint", "event": "odk-instance-first-load"},
     },
+    "background-audio": {
+        "control": {"tag": "action"},
+        "bind": {"type": "binary"},
+        "action": {"name": "odk:recordaudio", "event": "odk-instance-load"},
+    },
 }
